Changed project name from fluo-stress to Stresso

* Updated org to astralway
* Improved scripts to use 'fluo exec' and shaded jar
* Simplified how Stress is configured by 'env.sh'
diff --git a/.travis.yml b/.travis.yml
index b5ee8b7..5434a80 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -1,11 +1,11 @@
-# Copyright 2015 Fluo authors (see AUTHORS)
+# Copyright 2015 Stresso authors (see AUTHORS)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
diff --git a/README.md b/README.md
index 232cf4e..47564c6 100644
--- a/README.md
+++ b/README.md
@@ -1,20 +1,18 @@
 
-Fluo Stress
-===========
+# Stresso
 
-[![Build Status](https://travis-ci.org/fluo-io/fluo-stress.svg?branch=master)](https://travis-ci.org/fluo-io/fluo-stress)
+[![Build Status](https://travis-ci.org/astralway/stresso.svg?branch=master)](https://travis-ci.org/astralway/stresso)
 
-An example application designed to stress Fluo.  This Fluo application computes the 
+An example application designed to stress Apache Fluo.  This Fluo application computes the 
 number of unique integers through the process of building a bitwise trie.  New numbers
 are added to the trie as leaf nodes.  Observers watch all nodes in the trie to create 
 parents and percolate counts up to the root nodes such that each node in the trie keeps
 track of the number of leaf nodes below it. The count at the root nodes should equal 
 the total number of leaf nodes.  This makes it easy to verify if the test ran correctly. 
-The test stresses Fluo in that multiple transactions can operate on the same data as 
-counts are percolated up the trie.
+The test stresses Apache Fluo in that multiple transactions can operate on the same data
+as counts are percolated up the trie.
 
-Concepts and definitions
-------------------------
+## Concepts and definitions
 
 This test has the following set of configurable parameters.
 
@@ -57,28 +55,25 @@
 For small scale test a max of 10<sup>9</sup> and a stop level of 6 is a good
 choice. 
 
-Building stress test
---------------------
+## Building Stresso
 
 ```
 mvn package 
 ```
 
-This will create a jar in target:
+This will create a jar and shaded jar in target:
 
 ```
-$ ls target/fluo-stress-*
-target/fluo-stress-0.0.1-SNAPSHOT.jar  
+$ ls target/stresso-*
+target/stresso-0.0.1-SNAPSHOT.jar  target/stresso-0.0.1-SNAPSHOT-shaded.jar
 ```
 
-Run trie stress test using Mini Fluo
-----------------------------------------
+## Run Stresso using MiniFluo
 
-There are several integration tests that run the trie stress test on a MiniFluo instance.
+There are several integration tests that run Stresso on a MiniFluo instance.
 These tests can be run using `mvn verify`.
 
-Run trie stress test on cluster
--------------------------------
+## Run Stresso on cluster
 
 The [bin directory](/bin) contains a set of scripts to help run this test on a
 cluster.  These scripts make the following assumpitions.
@@ -91,24 +86,23 @@
 to `conf/env.sh`, then inspect and modify the file.
 
 Next, execute the [run-test.sh](/bin/run-test.sh) script.  This script will create a
-new fluo app called `stress` (which can be changed by `FLUO_APP_NAME` in your env.sh). 
-It will modify the application's fluo.properties, copy the stress jar to the `lib/` 
+new Apache Fluo app called `stresso` (which can be changed by `FLUO_APP_NAME` in your env.sh). 
+It will modify the application's fluo.properties, copy the stresso jar to the `lib/` 
 directory of the app and set the following in fluo.properties:
 
 ```
-io.fluo.observer.0=io.fluo.stress.trie.NodeObserver
-io.fluo.app.trie.nodeSize=X
-io.fluo.app.trie.stopLevel=Y
+fluo.observer.0=stresso.trie.NodeObserver
+fluo.app.trie.nodeSize=X
+fluo.app.trie.stopLevel=Y
 ```
 
-The `run-test.sh` script will then initialize and start the Fluo 'stress' application.  
+The `run-test.sh` script will then initialize and start the Stresso application.  
 It will load a lot of data directly into Accumulo without transactions and then 
 incrementally load smaller amounts of data using transactions.  After incrementally 
 loading some data, it computes the expected number of unique integers using map reduce.
-It then prints the number of unique integers computed by Fluo. 
+It then prints the number of unique integers computed by Apache Fluo. 
 
-Additional Scripts
-------------------
+## Additional Scripts
 
 The script [generate.sh](/bin/generate.sh) starts a map reduce job to generate
 random integers.
@@ -124,7 +118,7 @@
 out dir   = Output directory
 ```
 
-The script [split.sh](/bin/split.sh) pre-splits the Accumulo table used by
+The script [split.sh](/bin/split.sh) pre-splits the Accumulo table used by Apache
 Fluo.  Consider running this command before loading data.
 
 ```
@@ -134,7 +128,7 @@
 
 num tablets = Num tablets to create for lowest level of tree.  Will create less tablets for higher levels based on the max.
 ```
-After generating random numbers, load them into Fluo with one of the following
+After generating random numbers, load them into Apache Fluo with one of the following
 commands.  The script [init.sh](/bin/init.sh) intializes any empty table using
 map reduce.  This simulates the case where a user has a lot of initial data to
 load into Fluo.  This command should only be run when the table is empty
@@ -145,7 +139,7 @@
 
 where:
 
-input dir    = A directory with file created by io.fluo.stress.trie.Generate
+input dir    = A directory with file created by stresso.trie.Generate
 node size    = Size of node in bits which must be a divisor of 32/64
 tmp dir      = This command runs two map reduce jobs and needs an intermediate directory to store data.
 num reducers = Number of reduce task map reuduce job should run
@@ -160,7 +154,7 @@
 ```
 
 After loading data, run the [print.sh](/bin/print.sh) script to check the
-status of the computation of the number of unique integers within Fluo.  This
+status of the computation of the number of unique integers within Apache Fluo.  This
 command will print two numbers, the sum of the root nodes and number of root
 nodes.  If there are outstanding notification to process, this count may not be
 accurate.
diff --git a/bin/compact-ll.sh b/bin/compact-ll.sh
index c279eb7..5a98277 100755
--- a/bin/compact-ll.sh
+++ b/bin/compact-ll.sh
@@ -3,5 +3,4 @@
 BIN_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
 . $BIN_DIR/load-env.sh
 
-yarn jar $STRESS_JAR io.fluo.stress.trie.CompactLL $FLUO_PROPS $@
-
+$FLUO_CMD exec $FLUO_APP_NAME stresso.trie.CompactLL $FLUO_PROPS $@
diff --git a/bin/diff.sh b/bin/diff.sh
index 929d0a2..5e36d95 100755
--- a/bin/diff.sh
+++ b/bin/diff.sh
@@ -3,6 +3,4 @@
 BIN_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
 . $BIN_DIR/load-env.sh
 
-
-yarn jar $STRESS_JAR io.fluo.stress.trie.Diff $FLUO_PROPS $@
-
+$FLUO_CMD exec $FLUO_APP_NAME stresso.trie.Diff $FLUO_PROPS $@
diff --git a/bin/generate.sh b/bin/generate.sh
index f675489..622be8a 100755
--- a/bin/generate.sh
+++ b/bin/generate.sh
@@ -3,6 +3,4 @@
 BIN_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
 . $BIN_DIR/load-env.sh
 
-LJO="-libjars $LIB_JARS"
-yarn jar $STRESS_JAR io.fluo.stress.trie.Generate $LJO $@
-
+yarn jar $STRESSO_JAR stresso.trie.Generate $@
diff --git a/bin/init.sh b/bin/init.sh
index f7de70f..133ad10 100755
--- a/bin/init.sh
+++ b/bin/init.sh
@@ -3,12 +3,9 @@
 BIN_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
 . $BIN_DIR/load-env.sh
 
-
 if [ "$#" -ne 3 ]; then
     echo "Usage : $0 <input dir> <work dir> <num reducers>"
     exit 1
 fi
 
-LJO="-libjars $LIB_JARS"
-yarn jar $STRESS_JAR io.fluo.stress.trie.Init -Dmapreduce.job.reduces=$3 $LJO $FLUO_PROPS $1 $2
-
+yarn jar $STRESSO_SHADED_JAR stresso.trie.Init -Dmapreduce.job.reduces=$3 $FLUO_PROPS $1 $2
diff --git a/bin/load-env.sh b/bin/load-env.sh
index 7e0a1dc..5400fc2 100644
--- a/bin/load-env.sh
+++ b/bin/load-env.sh
@@ -5,25 +5,32 @@
   . $BIN_DIR/../conf/env.sh
 fi
 
-if [ ! -d "$FLUO_HOME" ]
-then
+# verify fluo configuration
+if [ ! -d "$FLUO_HOME" ]; then
   echo "Problem with FLUO_HOME : $FLUO_HOME"
   exit 1
 fi
-
+FLUO_CMD=$FLUO_HOME/bin/fluo
 if [ -z "$FLUO_APP_NAME" ]; then
   echo "FLUO_APP_NAME is not set!" 
   exit 1
 fi
-
+FLUO_APP_LIB=$FLUO_HOME/apps/$FLUO_APP_NAME/lib
+FLUO_PROPS=$FLUO_HOME/apps/$FLUO_APP_NAME/conf/fluo.properties
 if [ ! -f "$FLUO_PROPS" ] && [ -z "$SKIP_FLUO_PROPS_CHECK" ]; then
   echo "Fluo properties file not found : $FLUO_PROPS" 
   exit 1
 fi
 
-if [ ! -f "$STRESS_JAR" ] && [ -z "$SKIP_STRESS_JAR_CHECK" ]
-then
-  echo "Stress jar not found : $STRESS_JAR" 
+STRESSO_VERSION=0.0.1-SNAPSHOT
+STRESSO_JAR=$BIN_DIR/../target/stresso-$STRESSO_VERSION.jar
+STRESSO_SHADED_JAR=$BIN_DIR/../target/stresso-$STRESSO_VERSION-shaded.jar
+if [ ! -f "$STRESSO_JAR" ] && [ -z "$SKIP_JAR_CHECKS" ]; then
+  echo "Stresso jar not found : $STRESSO_JAR" 
+  exit 1;
+fi
+if [ ! -f "$STRESSO_SHADED_JAR" ] && [ -z "$SKIP_JAR_CHECKS" ]; then
+  echo "Stresso shaded jar not found : $STRESSO_SHADED_JAR" 
   exit 1;
 fi
 
diff --git a/bin/load.sh b/bin/load.sh
index a4a3a63..8cf2ac5 100755
--- a/bin/load.sh
+++ b/bin/load.sh
@@ -3,7 +3,4 @@
 BIN_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
 . $BIN_DIR/load-env.sh
 
-
-LJO="-libjars $LIB_JARS"
-yarn jar $STRESS_JAR io.fluo.stress.trie.Load $LJO $FLUO_PROPS $@
-
+yarn jar $STRESSO_SHADED_JAR stresso.trie.Load $FLUO_PROPS $@
diff --git a/bin/print.sh b/bin/print.sh
index 348f625..2554c4c 100755
--- a/bin/print.sh
+++ b/bin/print.sh
@@ -3,6 +3,4 @@
 BIN_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
 . $BIN_DIR/load-env.sh
 
-
-yarn jar $STRESS_JAR io.fluo.stress.trie.Print $FLUO_PROPS $@
-
+$FLUO_CMD exec $FLUO_APP_NAME stresso.trie.Print $FLUO_PROPS $@
diff --git a/bin/split.sh b/bin/split.sh
index d214b9c..becfd7c 100755
--- a/bin/split.sh
+++ b/bin/split.sh
@@ -3,5 +3,4 @@
 BIN_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
 . $BIN_DIR/load-env.sh
 
-yarn jar $STRESS_JAR io.fluo.stress.trie.Split $FLUO_PROPS $@
-
+$FLUO_CMD exec $FLUO_APP_NAME stresso.trie.Split $FLUO_PROPS $@
diff --git a/bin/unique.sh b/bin/unique.sh
index cbfbcee..68c2a58 100755
--- a/bin/unique.sh
+++ b/bin/unique.sh
@@ -8,7 +8,4 @@
     exit 1
 fi
 
-
-LJO="-libjars $LIB_JARS"
-yarn jar $STRESS_JAR io.fluo.stress.trie.Unique -Dmapreduce.job.reduces=$1 $LJO ${@:2}
-
+yarn jar $STRESSO_JAR stresso.trie.Unique -Dmapreduce.job.reduces=$1 ${@:2}
diff --git a/conf/env.sh.example b/conf/env.sh.example
index 52fe4ce..71720c9 100644
--- a/conf/env.sh.example
+++ b/conf/env.sh.example
@@ -1,47 +1,33 @@
-# Uncomment and set if FLUO_HOME is not set in your environment
-# #FLUO_HOME=/path/to/fluo-install
-#
-##############################
-#configuration for all scripts
-##############################
-#Must set Fluo, Accumulo and Zookeeper jars for following two options.
-export HADOOP_CLASSPATH=`$FLUO_HOME/bin/fluo classpath -a -z`
-LIB_JARS=`$FLUO_HOME/bin/fluo classpath -a -z -l`
-#location of the stress jar
-STRESS_JAR=$BIN_DIR/../target/fluo-stress-0.0.1-SNAPSHOT.jar
-#application name
-test -z "$FLUO_APP_NAME" && FLUO_APP_NAME=stress
-#location of Flup properties file
-FLUO_PROPS=$FLUO_HOME/apps/$FLUO_APP_NAME/conf/fluo.properties
+###############################
+# configuration for all scripts
+###############################
+# Fluo Home
+test -z "$FLUO_HOME" && FLUO_HOME=/path/to/accumulo
+# Fluo application name
+FLUO_APP_NAME=stresso
 
-######################################
-#configuration for run-test.sh follows
-######################################
-#Place where logs from test are placed
+###############################
+# configuration for run-test.sh
+###############################
+# Place where logs from test are placed
 LOG_DIR=$BIN_DIR/../logs
-#the maximum number to generate
+# Maximum number to generate
 MAX=$((10**9))
 #the number of splits to create in table
 SPLITS=17
-#number of mappers to run for data generation, which determines how many files
-#generation outputs.  The number of files determines how many mappers loading
-#data will run.
+# Number of mappers to run for data generation, which determines how many files
+# generation outputs.  The number of files determines how many mappers loading
+# data will run.
 MAPS=17
-#Number of reduce tasks
+# Number of reduce tasks
 REDUCES=17
-#Number of random numbers to generate initially
+# Number of random numbers to generate initially
 GEN_INIT=$((10**6))
-#Number of random numbers to generate for each incremental step.
+# Number of random numbers to generate for each incremental step.
 GEN_INCR=$((10**3))
-#Number of incremental steps.
+# Number of incremental steps.
 ITERATIONS=3
-#Seconds to sleep between incremental steps.
+# Seconds to sleep between incremental steps.
 SLEEP=30
-#Compact levels with less than the following possible nodes after loads
+# Compact levels with less than the following possible nodes after loads
 COMPACT_CUTOFF=$((256**3 + 1))
-
-########################
-#config for init-fluo.sh
-########################
-#Determines whether to attempt to build stress jar
-BUILD=true
diff --git a/src/main/resources/log4j.xml b/conf/log4j.xml
similarity index 95%
rename from src/main/resources/log4j.xml
rename to conf/log4j.xml
index fde5181..bd82a3a 100644
--- a/src/main/resources/log4j.xml
+++ b/conf/log4j.xml
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
-  Copyright 2015 Fluo authors (see AUTHORS)
+  Copyright 2015 Stresso authors (see AUTHORS)
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
@@ -27,11 +27,11 @@
 	<logger name="org.apache.zookeeper">
 		<level value="ERROR" />
 	</logger>
-	
+
 	<logger name="org.apache.curator">
 		<level value="ERROR" />
 	</logger>
-	
+
 	<root>
 		<level value="INFO" />
 		<appender-ref ref="console" />
diff --git a/pom.xml b/pom.xml
index 33b62db..2464c34 100644
--- a/pom.xml
+++ b/pom.xml
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
-  Copyright 2014 Fluo authors (see AUTHORS)
+  Copyright 2014 Stresso authors (see AUTHORS)
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
@@ -17,20 +17,14 @@
 <project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
   <modelVersion>4.0.0</modelVersion>
 
-  <groupId>io.fluo</groupId>
-  <artifactId>fluo-stress</artifactId>
+  <groupId>io.github.astralway</groupId>
+  <artifactId>stresso</artifactId>
   <version>0.0.1-SNAPSHOT</version>
   <packaging>jar</packaging>
 
-  <name>Fluo Stress</name>
-  <description>
-    This repo contains the Fluo stress tests.  Stress tests are different than integration tests in
-    that they are designed to run on a cluster while integration tests only run on MiniFluo in a 
-    local environment.  This repo produces the jar needed to run a stress test on a cluster.
-    Currently, this repo only has one stress test (the Trie test) but other tests could be added 
-    in the future.  
-  </description>
-  <url>https://github.com/fluo-io/fluo-stress</url>
+  <name>Stresso</name>
+  <description>This repo contains an example application designed to stress Apache Fluo</description>
+  <url>https://github.com/astralway/stresso</url>
 
   <properties>
     <accumulo.version>1.6.4</accumulo.version>
@@ -91,8 +85,8 @@
         <artifactId>maven-failsafe-plugin</artifactId>
         <configuration>
           <systemPropertyVariables>
-            <io.fluo.it.instance.name>it-instance-maven</io.fluo.it.instance.name>
-            <io.fluo.it.instance.clear>false</io.fluo.it.instance.clear>
+            <fluo.it.instance.name>it-instance-maven</fluo.it.instance.name>
+            <fluo.it.instance.clear>false</fluo.it.instance.clear>
           </systemPropertyVariables>
         </configuration>
         <executions>
@@ -106,6 +100,33 @@
         </executions>
       </plugin>
 
+      <plugin>
+        <groupId>org.apache.maven.plugins</groupId>
+        <artifactId>maven-shade-plugin</artifactId>
+        <executions>
+          <execution>
+            <goals>
+              <goal>shade</goal>
+            </goals>
+            <phase>package</phase>
+            <configuration>
+              <shadedArtifactAttached>true</shadedArtifactAttached>
+              <shadedClassifierName>shaded</shadedClassifierName>
+              <filters>
+                <filter>
+                  <artifact>*:*</artifact>
+                  <excludes>
+                    <exclude>META-INF/*.SF</exclude>
+                    <exclude>META-INF/*.DSA</exclude>
+                    <exclude>META-INF/*.RSA</exclude>
+                  </excludes>
+                </filter>
+              </filters>
+            </configuration>
+          </execution>
+        </executions>
+      </plugin>
+
     </plugins>
   </build>
 
@@ -192,7 +213,6 @@
       <version>${fluo.version}</version>
       <scope>test</scope>
     </dependency>
-
     <dependency>
       <groupId>commons-io</groupId>
       <artifactId>commons-io</artifactId>
diff --git a/src/main/java/io/fluo/stress/trie/CompactLL.java b/src/main/java/stresso/trie/CompactLL.java
similarity index 98%
rename from src/main/java/io/fluo/stress/trie/CompactLL.java
rename to src/main/java/stresso/trie/CompactLL.java
index 30cd9c6..1e0e421 100644
--- a/src/main/java/io/fluo/stress/trie/CompactLL.java
+++ b/src/main/java/stresso/trie/CompactLL.java
@@ -1,4 +1,4 @@
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.io.File;
 
diff --git a/src/main/java/io/fluo/stress/trie/Constants.java b/src/main/java/stresso/trie/Constants.java
similarity index 93%
rename from src/main/java/io/fluo/stress/trie/Constants.java
rename to src/main/java/stresso/trie/Constants.java
index 4e6ccb5..7c8cf6c 100644
--- a/src/main/java/io/fluo/stress/trie/Constants.java
+++ b/src/main/java/stresso/trie/Constants.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -11,14 +11,14 @@
  * or implied. See the License for the specific language governing permissions and limitations under
  * the License.
  */
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import org.apache.fluo.api.data.Column;
 import org.apache.fluo.recipes.core.types.StringEncoder;
 import org.apache.fluo.recipes.core.types.TypeLayer;
 
 /**
- * 
+ *
  */
 public class Constants {
 
diff --git a/src/main/java/io/fluo/stress/trie/Diff.java b/src/main/java/stresso/trie/Diff.java
similarity index 98%
rename from src/main/java/io/fluo/stress/trie/Diff.java
rename to src/main/java/stresso/trie/Diff.java
index aacf7dd..f74521d 100644
--- a/src/main/java/io/fluo/stress/trie/Diff.java
+++ b/src/main/java/stresso/trie/Diff.java
@@ -1,4 +1,4 @@
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.io.File;
 import java.util.ArrayList;
diff --git a/src/main/java/io/fluo/stress/trie/Generate.java b/src/main/java/stresso/trie/Generate.java
similarity index 91%
rename from src/main/java/io/fluo/stress/trie/Generate.java
rename to src/main/java/stresso/trie/Generate.java
index 4388c5c..55f9beb 100644
--- a/src/main/java/io/fluo/stress/trie/Generate.java
+++ b/src/main/java/stresso/trie/Generate.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.io.DataInput;
 import java.io.DataOutput;
@@ -22,7 +22,6 @@
 import java.util.Random;
 
 import com.google.common.base.Preconditions;
-import org.apache.fluo.api.config.FluoConfiguration;
 import org.apache.hadoop.conf.Configured;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.LongWritable;
@@ -44,9 +43,9 @@
 
   private static final Logger log = LoggerFactory.getLogger(Generate.class);
 
-  public static final String TRIE_GEN_NUM_PER_MAPPER_PROP = FluoConfiguration.FLUO_PREFIX + ".stress.trie.numPerMapper";
-  public static final String TRIE_GEN_NUM_MAPPERS_PROP = FluoConfiguration.FLUO_PREFIX + ".stress.trie.numMappers";
-  public static final String TRIE_GEN_MAX_PROP = FluoConfiguration.FLUO_PREFIX + ".stress.trie.max";
+  public static final String TRIE_GEN_NUM_PER_MAPPER_PROP = "stresso.trie.numPerMapper";
+  public static final String TRIE_GEN_NUM_MAPPERS_PROP = "stresso.trie.numMappers";
+  public static final String TRIE_GEN_MAX_PROP = "stresso.trie.max";
 
   public static class RandomSplit implements InputSplit {
 
diff --git a/src/main/java/io/fluo/stress/trie/Init.java b/src/main/java/stresso/trie/Init.java
similarity index 98%
rename from src/main/java/io/fluo/stress/trie/Init.java
rename to src/main/java/stresso/trie/Init.java
index 581dcde..8e7076b 100644
--- a/src/main/java/io/fluo/stress/trie/Init.java
+++ b/src/main/java/stresso/trie/Init.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.io.BufferedOutputStream;
 import java.io.File;
diff --git a/src/main/java/io/fluo/stress/trie/Load.java b/src/main/java/stresso/trie/Load.java
similarity index 96%
rename from src/main/java/io/fluo/stress/trie/Load.java
rename to src/main/java/stresso/trie/Load.java
index b6cb7a8..8e1ebfb 100644
--- a/src/main/java/io/fluo/stress/trie/Load.java
+++ b/src/main/java/stresso/trie/Load.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -12,7 +12,7 @@
  * the License.
  */
 
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.io.File;
 import java.io.IOException;
diff --git a/src/main/java/io/fluo/stress/trie/Node.java b/src/main/java/stresso/trie/Node.java
similarity index 94%
rename from src/main/java/io/fluo/stress/trie/Node.java
rename to src/main/java/stresso/trie/Node.java
index a51ed9e..fb45a60 100644
--- a/src/main/java/io/fluo/stress/trie/Node.java
+++ b/src/main/java/stresso/trie/Node.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import com.google.common.base.Strings;
 import com.google.common.hash.Hashing;
@@ -23,19 +23,19 @@
 /** Utility class that represents trie node
  */
 public class Node {
-  
-  private final Number number; 
+
+  private final Number number;
   private final int level;
   private final int nodeSize;
-  
+
   static final int HASH_LEN=4;
-  
+
   public Node(Number number, int level, int nodeSize) {
     this.number = number;
     this.level = level;
     this.nodeSize = nodeSize;
   }
-  
+
   public Node(String rowId) {
     String[] rowArgs = rowId.split(":");
     checkArgument(validRowId(rowArgs), "Invalid row id - "+ rowId);
@@ -43,23 +43,23 @@
     this.nodeSize = Integer.parseInt(rowArgs[2]);
     this.number = parseNumber(rowArgs[3]);
   }
-  
+
   public Number getNumber() {
     return number;
   }
-  
+
   public int getLevel() {
     return level;
   }
-  
+
   public boolean isRoot() {
     return level == 0;
   }
-  
+
   public int getNodeSize() {
     return nodeSize;
   }
-  
+
   private Number parseNumber(String numStr) {
     if (numStr.equals("root")) {
       return null;
@@ -69,7 +69,7 @@
       return Integer.parseInt(numStr, 16);
     }
   }
-  
+
   private String genHash(){
     long num = (number == null)? 0l : number.longValue();
     int hash = Hashing.murmur3_32().newHasher().putInt(level).putInt(nodeSize).putLong(num).hash().asInt();
@@ -78,11 +78,11 @@
     String hashString = Strings.padStart(Integer.toString(hash, Character.MAX_RADIX), HASH_LEN, '0');
     return hashString.substring(hashString.length() - HASH_LEN);
   }
-  
+
   public String getRowId() {
     if (level == 0) {
-      return String.format("00:%s:%02d:root", genHash(), nodeSize); 
-    } else { 
+      return String.format("00:%s:%02d:root", genHash(), nodeSize);
+    } else {
       if (number instanceof Integer) {
         return String.format("%02d:%s:%02d:%08x", level, genHash(), nodeSize, number);
       } else {
@@ -90,11 +90,11 @@
       }
     }
   }
-  
+
   public Node getParent() {
     if (level == 1) {
       return new Node(null, 0, nodeSize);
-    } else {   
+    } else {
       if (number instanceof Long) {
         int shift = (((64 / nodeSize) - level) * nodeSize) + nodeSize;
         Long parent = (number.longValue() >> shift) << shift;
@@ -104,13 +104,13 @@
         Integer parent = (number.intValue() >> shift) << shift;
         return new Node(parent, level-1, nodeSize);
       }
-    }  
+    }
   }
-    
+
   private boolean validRowId(String[] rowArgs) {
     return ((rowArgs.length == 4) && (rowArgs[0] != null) && (rowArgs[1] != null) && (rowArgs[2] != null) && (rowArgs[3] != null));
   }
-  
+
   public static String generateRootId(int nodeSize) {
     return (new Node(null, 0, nodeSize)).getRowId();
   }
diff --git a/src/main/java/io/fluo/stress/trie/NodeObserver.java b/src/main/java/stresso/trie/NodeObserver.java
similarity index 97%
rename from src/main/java/io/fluo/stress/trie/NodeObserver.java
rename to src/main/java/stresso/trie/NodeObserver.java
index f84249b..d7356c5 100644
--- a/src/main/java/io/fluo/stress/trie/NodeObserver.java
+++ b/src/main/java/stresso/trie/NodeObserver.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -11,7 +11,7 @@
  * or implied. See the License for the specific language governing permissions and limitations under
  * the License.
  */
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.util.Map;
 
diff --git a/src/main/java/io/fluo/stress/trie/NumberLoader.java b/src/main/java/stresso/trie/NumberLoader.java
similarity index 96%
rename from src/main/java/io/fluo/stress/trie/NumberLoader.java
rename to src/main/java/stresso/trie/NumberLoader.java
index 492556b..961893a 100644
--- a/src/main/java/io/fluo/stress/trie/NumberLoader.java
+++ b/src/main/java/stresso/trie/NumberLoader.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -11,7 +11,7 @@
  * or implied. See the License for the specific language governing permissions and limitations under
  * the License.
  */
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.util.Map;
 
diff --git a/src/main/java/io/fluo/stress/trie/Print.java b/src/main/java/stresso/trie/Print.java
similarity index 97%
rename from src/main/java/io/fluo/stress/trie/Print.java
rename to src/main/java/stresso/trie/Print.java
index b835450..62c39a8 100644
--- a/src/main/java/io/fluo/stress/trie/Print.java
+++ b/src/main/java/stresso/trie/Print.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -12,7 +12,7 @@
  * the License.
  */
 
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.io.File;
 
diff --git a/src/main/java/io/fluo/stress/trie/Split.java b/src/main/java/stresso/trie/Split.java
similarity index 97%
rename from src/main/java/io/fluo/stress/trie/Split.java
rename to src/main/java/stresso/trie/Split.java
index ca8de57..898a6a9 100644
--- a/src/main/java/io/fluo/stress/trie/Split.java
+++ b/src/main/java/stresso/trie/Split.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -12,7 +12,7 @@
  * the License.
  */
 
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.io.File;
 import java.util.TreeSet;
diff --git a/src/main/java/io/fluo/stress/trie/Unique.java b/src/main/java/stresso/trie/Unique.java
similarity index 96%
rename from src/main/java/io/fluo/stress/trie/Unique.java
rename to src/main/java/stresso/trie/Unique.java
index 862f8fb..ef0d1cc 100644
--- a/src/main/java/io/fluo/stress/trie/Unique.java
+++ b/src/main/java/stresso/trie/Unique.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package io.fluo.stress.trie;
+package stresso.trie;
 
 import java.io.IOException;
 import java.util.Iterator;
@@ -45,7 +45,7 @@
   public static enum Stats {
     UNIQUE;
   }
-  
+
   public static class UniqueReducer extends MapReduceBase implements Reducer<LongWritable,NullWritable,LongWritable,NullWritable> {
     @Override
     public void reduce(LongWritable key, Iterator<NullWritable> values, OutputCollector<LongWritable,NullWritable> output, Reporter reporter) throws IOException {
@@ -83,17 +83,17 @@
     job.setMapOutputValueClass(NullWritable.class);
 
     job.setReducerClass(UniqueReducer.class);
-    
+
     job.setOutputFormat(NullOutputFormat.class);
-    
+
     RunningJob runningJob = JobClient.runJob(job);
     runningJob.waitForCompletion();
     numUnique = (int) runningJob.getCounters().getCounter(Stats.UNIQUE);
-    
+
     log.debug("numUnique : "+numUnique);
-    
+
     return runningJob.isSuccessful() ? 0 : -1;
-    
+
   }
 
   public static void main(String[] args) throws Exception {
diff --git a/src/test/java/io/fluo/stress/TrieBasicIT.java b/src/test/java/stresso/TrieBasicIT.java
similarity index 91%
rename from src/test/java/io/fluo/stress/TrieBasicIT.java
rename to src/test/java/stresso/TrieBasicIT.java
index 2155882..ba4867c 100644
--- a/src/test/java/io/fluo/stress/TrieBasicIT.java
+++ b/src/test/java/stresso/TrieBasicIT.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -11,7 +11,7 @@
  * or implied. See the License for the specific language governing permissions and limitations under
  * the License.
  */
-package io.fluo.stress;
+package stresso;
 
 import java.util.Collections;
 import java.util.HashSet;
@@ -19,10 +19,6 @@
 import java.util.Random;
 import java.util.Set;
 
-import io.fluo.stress.trie.Constants;
-import io.fluo.stress.trie.Node;
-import io.fluo.stress.trie.NodeObserver;
-import io.fluo.stress.trie.NumberLoader;
 import org.apache.fluo.api.client.FluoClient;
 import org.apache.fluo.api.client.FluoFactory;
 import org.apache.fluo.api.client.LoaderExecutor;
@@ -34,9 +30,13 @@
 import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import stresso.trie.Constants;
+import stresso.trie.Node;
+import stresso.trie.NodeObserver;
+import stresso.trie.NumberLoader;
 
-import static io.fluo.stress.trie.Constants.COUNT_SEEN_COL;
-import static io.fluo.stress.trie.Constants.TYPEL;
+import static stresso.trie.Constants.COUNT_SEEN_COL;
+import static stresso.trie.Constants.TYPEL;
 
 /**
  * Tests Trie Stress Test using Basic Loader
diff --git a/src/test/java/io/fluo/stress/TrieMapRedIT.java b/src/test/java/stresso/TrieMapRedIT.java
similarity index 93%
rename from src/test/java/io/fluo/stress/TrieMapRedIT.java
rename to src/test/java/stresso/TrieMapRedIT.java
index 35dceee..c6338e6 100644
--- a/src/test/java/io/fluo/stress/TrieMapRedIT.java
+++ b/src/test/java/stresso/TrieMapRedIT.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -11,7 +11,7 @@
  * or implied. See the License for the specific language governing permissions and limitations under
  * the License.
  */
-package io.fluo.stress;
+package stresso;
 
 import java.io.File;
 import java.util.ArrayList;
@@ -19,13 +19,6 @@
 import java.util.Collections;
 import java.util.List;
 
-import io.fluo.stress.trie.Constants;
-import io.fluo.stress.trie.Generate;
-import io.fluo.stress.trie.Init;
-import io.fluo.stress.trie.Load;
-import io.fluo.stress.trie.NodeObserver;
-import io.fluo.stress.trie.Print;
-import io.fluo.stress.trie.Unique;
 import org.apache.commons.io.FileUtils;
 import org.apache.fluo.api.config.ObserverConfiguration;
 import org.apache.fluo.api.config.SimpleConfiguration;
@@ -33,6 +26,13 @@
 import org.apache.hadoop.util.ToolRunner;
 import org.junit.Assert;
 import org.junit.Test;
+import stresso.trie.Constants;
+import stresso.trie.Generate;
+import stresso.trie.Init;
+import stresso.trie.Load;
+import stresso.trie.NodeObserver;
+import stresso.trie.Print;
+import stresso.trie.Unique;
 
 /**
  * Tests Trie Stress Test using MapReduce Ingest
diff --git a/src/test/java/io/fluo/stress/TrieStopLevelIT.java b/src/test/java/stresso/TrieStopLevelIT.java
similarity index 89%
rename from src/test/java/io/fluo/stress/TrieStopLevelIT.java
rename to src/test/java/stresso/TrieStopLevelIT.java
index b9b10ca..a9f6901 100644
--- a/src/test/java/io/fluo/stress/TrieStopLevelIT.java
+++ b/src/test/java/stresso/TrieStopLevelIT.java
@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Fluo authors (see AUTHORS)
+ * Copyright 2014 Stresso authors (see AUTHORS)
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
  * in compliance with the License. You may obtain a copy of the License at
@@ -12,20 +12,20 @@
  * the License.
  */
 
-package io.fluo.stress;
+package stresso;
 
 import java.util.Collections;
 import java.util.List;
 
-import io.fluo.stress.trie.Constants;
-import io.fluo.stress.trie.Node;
-import io.fluo.stress.trie.NodeObserver;
 import org.apache.fluo.api.client.Snapshot;
 import org.apache.fluo.api.config.ObserverConfiguration;
 import org.apache.fluo.api.config.SimpleConfiguration;
 import org.apache.fluo.api.data.Bytes;
 import org.junit.Assert;
 import org.junit.Test;
+import stresso.trie.Constants;
+import stresso.trie.Node;
+import stresso.trie.NodeObserver;
 
 public class TrieStopLevelIT extends TrieMapRedIT {
 
diff --git a/src/test/resources/log4j.properties b/src/test/resources/log4j.properties
index e64f921..adf8e2e 100644
--- a/src/test/resources/log4j.properties
+++ b/src/test/resources/log4j.properties
@@ -1,4 +1,4 @@
-# Copyright 2014 Fluo authors (see AUTHORS)
+# Copyright 2014 Stresso authors (see AUTHORS)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,10 +18,9 @@
 log4j.appender.CA.layout.ConversionPattern=%d{ISO8601} [%c{2}] %-5p: %m%n
 
 log4j.logger.org.apache.curator=ERROR
-log4j.logger.org.apache.accumulo.core.client.impl.ServerClient=ERROR
-log4j.logger.org.apache.accumulo.core.util.shell.Shell.audit=off
-log4j.logger.org.apache.accumulo.core.util.shell.Shell=FATAL
+log4j.logger.org.apache.accumulo=WARN
 log4j.logger.org.apache.commons.vfs2.impl.DefaultFileSystemManager=WARN
+log4j.logger.org.apache.fluo=WARN
 log4j.logger.org.apache.hadoop=WARN
 log4j.logger.org.apache.hadoop.conf=ERROR
 log4j.logger.org.apache.hadoop.mapred=ERROR
@@ -29,4 +28,4 @@
 log4j.logger.org.apache.hadoop.util.NativeCodeLoader=ERROR
 log4j.logger.org.apache.zookeeper.ClientCnxn=FATAL
 log4j.logger.org.apache.zookeeper.ZooKeeper=WARN
-log4j.logger.io.fluo=ERROR
+log4j.logger.stresso=WARN
diff --git a/bin/run-test.sh b/bin/run-test.sh
index 7ad54c3..36d62ec 100755
--- a/bin/run-test.sh
+++ b/bin/run-test.sh
@@ -1,40 +1,45 @@
 #!/bin/bash
 
 BIN_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
-SKIP_STRESS_JAR_CHECK="true"
+SKIP_JAR_CHECKS="true"
 SKIP_FLUO_PROPS_CHECK="true"
 
 . $BIN_DIR/load-env.sh
 
-unset SKIP_STRESS_JAR_CHECK
+unset SKIP_JAR_CHECKS
 unset SKIP_FLUO_PROPS_CHECK
 
+# stop if any command fails
+set -e
+
 if [ ! -d $FLUO_HOME/apps/$FLUO_APP_NAME ]; then
-  $FLUO_HOME/bin/fluo new $FLUO_APP_NAME
+  $FLUO_CMD new $FLUO_APP_NAME
 else
   echo "Restarting '$FLUO_APP_NAME' application.  Errors may be printed if it's not running..."
-  $FLUO_HOME/bin/fluo stop $FLUO_APP_NAME || true
+  $FLUO_CMD stop $FLUO_APP_NAME || true
   rm -rf $FLUO_HOME/apps/$FLUO_APP_NAME
-  $FLUO_HOME/bin/fluo new $FLUO_APP_NAME
+  $FLUO_CMD new $FLUO_APP_NAME
 fi
 
-if [ "$BUILD" = "true" ]; then
-  # build fluo-stress
-  (cd $BIN_DIR/..;mvn package -DskipTests)
-fi
+# build stresso
+(cd $BIN_DIR/..;mvn package -DskipTests)
 
 if [[ $(accumulo version) == *1.6* ]]; then
   # build stress balancer
   (cd $BIN_DIR/..; mkdir -p git; cd git;git clone https://github.com/keith-turner/stress-balancer.git; cd stress-balancer; ./config-fluo.sh $FLUO_PROPS)
 fi
 
-if [ ! -f "$STRESS_JAR" ]; then
-  echo "Stress jar not found : $STRESS_JAR" 
+if [ ! -f "$STRESSO_JAR" ]; then
+  echo "Stresso jar not found : $STRESSO_JAR"
   exit 1
 fi
-
-# copy stess jar
-cp $STRESS_JAR $FLUO_HOME/apps/$FLUO_APP_NAME/lib
+if [ ! -d $FLUO_APP_LIB ]; then
+  echo "Fluo app lib $FLUO_APP_LIB does not exist" 
+  exit 1
+fi
+cp $STRESSO_JAR $FLUO_APP_LIB
+fluo_recipes_version=1.0.0-incubating-SNAPSHOT
+mvn dependency:get -Dartifact=org.apache.fluo:fluo-recipes-core:$fluo_recipes_version:jar -Ddest=$FLUO_APP_LIB
 
 # determine a good stop level
 if (("$MAX" <= $((10**9)))); then
@@ -46,17 +51,18 @@
 fi
 
 # delete existing config in fluo.properties if it exist
-$SED '/io.fluo.observer/d' $FLUO_PROPS
-$SED '/io.fluo.app.trie/d' $FLUO_PROPS
+$SED '/fluo.observer/d' $FLUO_PROPS
+$SED '/fluo.app.trie/d' $FLUO_PROPS
 
-# append stress specific config
-echo "io.fluo.observer.0=io.fluo.stress.trie.NodeObserver" >> $FLUO_PROPS
-echo "io.fluo.app.trie.nodeSize=8" >> $FLUO_PROPS
-echo "io.fluo.app.trie.stopLevel=$STOP" >> $FLUO_PROPS
+# append stresso specific config
+echo "fluo.observer.0=stresso.trie.NodeObserver" >> $FLUO_PROPS
+echo "fluo.app.trie.nodeSize=8" >> $FLUO_PROPS
+echo "fluo.app.trie.stopLevel=$STOP" >> $FLUO_PROPS
 
-$FLUO_HOME/bin/fluo init $FLUO_APP_NAME -f
-$FLUO_HOME/bin/fluo start $FLUO_APP_NAME
+$FLUO_CMD init $FLUO_APP_NAME -f
+$FLUO_CMD start $FLUO_APP_NAME
 
+echo "Removing any previous logs in $LOG_DIR"
 mkdir -p $LOG_DIR
 rm -f $LOG_DIR/*
 
@@ -65,7 +71,10 @@
   (cd $BIN_DIR/../git/stress-balancer; ./config-accumulo.sh $FLUO_PROPS)
 fi # TODO setup RegexGroupBalancer built into Accumulo 1.7.0... may be easier to do from java
 
-hadoop fs -rm -r /stress/
+hadoop fs -rm -r -f /stresso/
+
+set -e
+
 # add splits to Fluo table
 echo "*****Presplitting table*****"
 $BIN_DIR/split.sh $SPLITS >$LOG_DIR/split.out 2>$LOG_DIR/split.err
@@ -73,16 +82,16 @@
 if (( GEN_INIT > 0 )); then
   # generate and load intial data using map reduce writing directly to table
   echo "*****Generating and loading initial data set*****"
-  $BIN_DIR/generate.sh $MAPS $((GEN_INIT / MAPS)) $MAX /stress/init >$LOG_DIR/generate_0.out 2>$LOG_DIR/generate_0.err
-  $BIN_DIR/init.sh /stress/init /stress/initTmp $REDUCES >$LOG_DIR/init.out 2>$LOG_DIR/init.err
-  hadoop fs -rm -r /stress/initTmp
+  $BIN_DIR/generate.sh $MAPS $((GEN_INIT / MAPS)) $MAX /stresso/init >$LOG_DIR/generate_0.out 2>$LOG_DIR/generate_0.err
+  $BIN_DIR/init.sh /stresso/init /stresso/initTmp $REDUCES >$LOG_DIR/init.out 2>$LOG_DIR/init.err
+  hadoop fs -rm -r /stresso/initTmp
 fi
 
 # load data incrementally
 for i in $(seq 1 $ITERATIONS); do
   echo "*****Generating and loading incremental data set $i*****"
-  $BIN_DIR/generate.sh $MAPS $((GEN_INCR / MAPS)) $MAX /stress/$i >$LOG_DIR/generate_$i.out 2>$LOG_DIR/generate_$i.err
-  $BIN_DIR/load.sh /stress/$i >$LOG_DIR/load_$i.out 2>$LOG_DIR/load_$i.err
+  $BIN_DIR/generate.sh $MAPS $((GEN_INCR / MAPS)) $MAX /stresso/$i >$LOG_DIR/generate_$i.out 2>$LOG_DIR/generate_$i.err
+  $BIN_DIR/load.sh /stresso/$i >$LOG_DIR/load_$i.out 2>$LOG_DIR/load_$i.err
   # TODO could reload the same dataset sometimes, maybe when i%5 == 0 or something
   $BIN_DIR/compact-ll.sh $MAX $COMPACT_CUTOFF >$LOG_DIR/compact-ll_$i.out 2>$LOG_DIR/compact-ll_$i.err
   sleep $SLEEP
@@ -90,11 +99,11 @@
 
 # print unique counts
 echo "*****Calculating # of unique integers using MapReduce*****"
-$BIN_DIR/unique.sh $REDUCES /stress/* >$LOG_DIR/unique.out 2>$LOG_DIR/unique.err
+$BIN_DIR/unique.sh $REDUCES /stresso/* >$LOG_DIR/unique.out 2>$LOG_DIR/unique.err
 grep UNIQUE $LOG_DIR/unique.err
 
 echo "*****Wait for Fluo to finish processing*****"
-$FLUO_HOME/bin/fluo wait $FLUO_APP_NAME
+$FLUO_CMD wait $FLUO_APP_NAME
 
 echo "*****Printing # of unique integers calculated by Fluo*****"
 $BIN_DIR/print.sh >$LOG_DIR/print.out 2>$LOG_DIR/print.err